@@ -113,3 +113,7 @@ pub const WINDOWSTYLE_NOCAPTION: windows_sys::Win32::UI::WindowsAndMessaging::WI
 #[cfg(unix)]
 /// Standard window
 pub const WINDOWSTYLE_NORMAL: gtk::WindowType = gtk::WindowType::Toplevel;
+
+#[cfg(windows)]
+#[cfg(feature="nxui-awc")]
+pub const ADVANCED_WINDOWSTYLE_UTILITY: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_EX_TOOLWINDOW;
