@@ -103,12 +103,48 @@ impl WindowAttributes {
     }
 }
 
+#[cfg(windows)]
+#[cfg(feature="nxui-awc")]
+pub struct AdvancedOptions {
+    advanced_style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE
+}
+
+#[cfg(windows)]
+#[cfg(feature="nxui-awc")]
+impl AdvancedOptions {
+    pub fn new(advanced_style: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE) -> Self {
+        Self {
+            advanced_style
+        }
+    }
+
+    pub fn get_style(&self) -> windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE {
+        self.advanced_style
+    }
+}
+
+#[cfg(windows)]
+#[cfg(feature="nxui-awc")]
+impl Default for AdvancedOptions {
+    fn default() -> Self {
+        Self {
+            advanced_style: 0
+        }
+    }
+}
+
 #[cfg(windows)]
 pub trait Application {
     /// Returns the name of the application.
     fn app_name(&self) -> String;
     /// Returns WindowAttributes.
     fn attributes(&self) -> WindowAttributes;
+
+    #[cfg(feature="nxui-awc")]
+    fn advanced_options(&self) -> AdvancedOptions {
+        AdvancedOptions::default()
+    }
+
     /// Processing at application startup (optional)
     fn startup(&self,storage: Storage) {
 
